# Test Coverage Report

Generated: Sat 2013-07-20 15:17 CEST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 222 | 193 | 28 | 99.5%
frequently.__init__ | 1 | 1 | 0 | 100.0%
frequently.forms | 37 | 30 | 7 | 100.0%
frequently.models | 47 | 36 | 10 | 97.3%
frequently.templatetags.frequently_tags | 10 | 8 | 2 | 100.0%
frequently.views | 127 | 118 | 9 | 100.0%

Excluded packages and modules
Error packages and modules